#BEGIN COPYRIGHT
#*************************************************************************
#
# Licensed Materials - Property of IBM
# 5725-C94, 5725-C95, 5725-C96
# (C) Copyright IBM Corporation 2012, 2013. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
#*************************************************************************
#END COPYRIGHT
import getopt

def getTargetsForApplication(application):
    targets = []
    deployment = AdminConfig.getid('/Deployment:%s/' % application);
    deploymentTargets = AdminUtilities.convertToList(AdminConfig.showAttribute(deployment, 'deploymentTargets'))
    for deploymentTarget in deploymentTargets:
        if AdminConfig.getObjectType(deploymentTarget) == 'ClusteredTarget':
            clusterName = AdminConfig.showAttribute(deploymentTarget, 'name')
            cluster = AdminConfig.getid('/ServerCluster:%s/' % clusterName)
            if cluster not in targets:
                targets.append(cluster)
        elif AdminConfig.getObjectType(deploymentTarget) == 'ServerTarget':
            serverName = AdminConfig.showAttribute(deploymentTarget, 'name')
            nodeName = AdminConfig.showAttribute(deploymentTarget, 'nodeName')
            print "Application " + application + " is deployed to server " + serverName + " on node " + nodeName + "."
            server = AdminConfig.getid('/Node:%s/Server:%s/' % (nodeName, serverName))
            if server not in targets:
                targets.append(server)
    return targets

#------------------------------------------------------------------------------
# Get clusters by topologyName
#------------------------------------------------------------------------------
def getClusters(topologyName):	
	topologyClusters = []	
	
	# identify the topology's clusters (in a certain order of preference)
	wbiClusters = AdminConfig.list('BPMCluster', AdminConfig.getid('/BPMDeploymentEnvironment:%s/' % topologyName)).splitlines()
	if wbiClusters:
		for capability in ['Application', 'Support', 'Messaging']:
			for wbiCluster in wbiClusters:
				clusterName = AdminConfig.showAttribute(wbiCluster, 'name')
				cluster = AdminConfig.getid('/ServerCluster:%s' % clusterName)
				capabilities = AdminConfig.showAttribute(wbiCluster, 'capabilities')
				if capabilities and capability in capabilities.split(';'):
					if cluster not in topologyClusters:
						topologyClusters.append(cluster)
		# add any other clusters
		for wbiCluster in wbiClusters:
			clusterName = AdminConfig.showAttribute(wbiCluster, 'name')
			cluster = AdminConfig.getid('/ServerCluster:%s' % clusterName)
			if cluster not in topologyClusters:
				topologyClusters.append(cluster)
				
	return 	topologyClusters
	
#------------------------------------------------------------------------------
# Map web modules to the virtual host that corresponds to the virtual host
#------------------------------------------------------------------------------
def updageVH(virtualHostName, topologyName):	
	topologyClusters = getClusters(topologyName)
	applications = AdminApp.list().splitlines()

	# map web modules to the virtual host that corresponds to the virtual hosts    
	for application in applications:
	    for target in getTargetsForApplication(application):
	        if target in topologyClusters:
	            print "Mapping web modules in application " + application + " to virtualHost " + virtualHostName
	            AdminApp.edit(application, ['-MapWebModToVH', [['.*', '.*', virtualHostName]]])
	            break;

#------------------------------------------------------------------------------
# Print script usage
#------------------------------------------------------------------------------
def usage():
	print
	print "Usage:"
	print
	print "   updateVirtualHost(.bat|.sh) [OPTIONS]"
	print
	print "   -d, --deployment-environment=DE_NAME1,DE_NAME2 Specify the deployment"
	print "                                        environment names."
	print "   -v, --virtual-host-name=virtual_host_name virtual host on which to map web modules"
	print "                                        in applications"
	print "       --no-sync                        Do not force the immediate propagation"
	print "                                        of changes across nodes."
	print "       --no-save                        Do not save configuration changes."
	print "       --help                           Display this help"
	print
	
#------------------------------------------------------------------------------
# Main entry point
#------------------------------------------------------------------------------	
def main():
	inputArgs = []
	i = 0
	while i < len(sys.argv):
		if sys.argv[i] == "-USER_INSTALL_ROOT":
			i = i + 2
		else:
			inputArgs.append(sys.argv[i])
			i = i + 1

	try:
		options, args = getopt.getopt(inputArgs, "d:v:", ["no-save","no-sync", "deployment-environment=", "virtual-host-name=", "help"])
	except getopt.GetoptError, err:
		print str(err)
		usage()
		return 2

	if args:
		usage()
	
	save = 1
	sync = 1
	topologyNames = None
	virtualHostName = None
	for option, arg in options:
		if option in ("-d", "--deployment-environment"):
			topologyNames = arg.split(',')
		elif option in ("-v", "--virtual-host-name"):
			virtualHostName = arg
		elif option == "--no-save":
			save = 0
			sync = 0
		elif option == "--no-sync":
			sync = 0
		elif option == "--help":
			usage()
			return
		else:
			assert 0, "un-handled option"
	
	if  topologyNames == None:
		usage()
	
	if  virtualHostName == None:
		usage()
	
	# map web modules to the virtual host that corresponds to the virtual host
	for topologyName in topologyNames:
		topology = AdminConfig.getid('/BPMDeploymentEnvironment:%s/' % topologyName)
		if topology:
			updageVH(virtualHostName, topologyName)
		else:
			raise "Deployment environment " + topologyName + " does not exist."
	
	# save and sync
	if save:
		print "Configuration is being saved."
		AdminConfig.save()
		if sync:
			print "Synchronizing the configuration across all nodes."
			AdminNodeManagement.syncActiveNodes()
		print "Done."
		

if __name__ == "__main__":
	sys.exit(main())
