<?xml version="1.0" encoding="UTF-8"?>
<!--
//BEGIN COPYRIGHT
//*************************************************************************
//
// Licensed Materials - Property of IBM
// 5725-C94, 5725-C95, 5725-C96
// (C) Copyright IBM Corporation 2013. All Rights Reserved.
// US Government Users Restricted Rights- Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.
//
//*************************************************************************
//END COPYRIGHT
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:ns="http://www.ibm.com/BPM/Migration/Performance">
<xsl:output method="text" omit-xml-declaration="no" indent="yes"/>
<xsl:strip-space elements="*"/>
<xsl:template match="ns:PerformanceFactors">
#######################################################################################################
# The performance tuning parameters
# If the parameter's value is empty, it means that it is not configured.
#######################################################################################################
<xsl:apply-templates select="*"/>
</xsl:template>
<xsl:template match="ns:JVM">
# JVM performance tuning parameters
<xsl:for-each select="ns:Server">
JVM.<xsl:value-of select="position()"/>.Server=<xsl:value-of select="@name"/>
JVM.<xsl:value-of select="position()"/>.genericJvmArguments=<xsl:value-of select="ns:ProcessDef/ns:jvmEntries/@genericJvmArguments"/>
JVM.<xsl:value-of select="position()"/>.initialHeapSize=<xsl:value-of select="ns:ProcessDef/ns:jvmEntries/@initialHeapSize"/>
JVM.<xsl:value-of select="position()"/>.maximumHeapSize=<xsl:value-of select="ns:ProcessDef/ns:jvmEntries/@maximumHeapSize"/>
JVM.<xsl:value-of select="position()"/>.verboseModeGarbageCollection=<xsl:value-of select="ns:ProcessDef/ns:jvmEntries/@verboseModeGarbageCollection"/>
</xsl:for-each>	    
</xsl:template>
<xsl:template match="ns:J2CCF">

# J2C Connection Factories performance tuning parameters
<xsl:for-each select="ns:factories">
J2CConnectionFactory.<xsl:value-of select="position()"/>.jndiName=<xsl:value-of select="@jndiName"/>
J2CConnectionFactory.<xsl:value-of select="position()"/>.maxConnections=<xsl:value-of select="ns:connectionPool/@maxConnections"/>
J2CConnectionFactory.<xsl:value-of select="position()"/>.minConnections=<xsl:value-of select="ns:connectionPool/@minConnections"/>
</xsl:for-each>	    
</xsl:template>
<xsl:template match="ns:J2CAS">

# J2C Activation Specification performance tuning parameters
<xsl:for-each select="ns:j2cActivationSpec">
J2CActivationSpec.<xsl:value-of select="position()"/>.jndiName=<xsl:value-of select="@jndiName"/>
J2CActivationSpec.<xsl:value-of select="position()"/>.maxBatchSize=<xsl:value-of select="@maxBatchSize"/>
J2CActivationSpec.<xsl:value-of select="position()"/>.maxConcurrency=<xsl:value-of select="@maxConcurrency"/>
</xsl:for-each>	    
</xsl:template>
<xsl:template match="ns:DataSource">

# DataSource performance tuning parameters
<xsl:for-each select="ns:factories">
DataSource.<xsl:value-of select="position()"/>.jndiName=<xsl:value-of select="@jndiName"/>
DataSource.<xsl:value-of select="position()"/>.maxConnections=<xsl:value-of select="ns:connectionPool/@maxConnections"/>
DataSource.<xsl:value-of select="position()"/>.minConnections=<xsl:value-of select="ns:connectionPool/@minConnections"/>
</xsl:for-each>	    
</xsl:template>
<xsl:template match="ns:ListenerPort">

# ListenerPort performance tuning parameters
<xsl:for-each select="ns:Server">
<xsl:variable name="level1Count" select="position()"/>
<xsl:if test="$level1Count!=1">
<xsl:call-template name="Newline" />
</xsl:if>
ListenerPort.<xsl:value-of select="$level1Count"/>.Server=<xsl:value-of select="@name"/>
<xsl:for-each select="ns:listenerPorts">
ListenerPort.<xsl:value-of select="$level1Count"/>.<xsl:value-of select="position()"/>.name=<xsl:value-of select="@name"/>
ListenerPort.<xsl:value-of select="$level1Count"/>.<xsl:value-of select="position()"/>.maxMessages=<xsl:value-of select="@maxMessages"/>
ListenerPort.<xsl:value-of select="$level1Count"/>.<xsl:value-of select="position()"/>.maxSessions=<xsl:value-of select="@maxSessions"/>
</xsl:for-each>	 
</xsl:for-each>	   
</xsl:template>
<xsl:template match="ns:ThreadPool">

# ThreadPool performance tuning parameters
<xsl:for-each select="ns:Server">
<xsl:variable name="level1Count" select="position()"/>
<xsl:if test="$level1Count!=1">
<xsl:call-template name="Newline" />
</xsl:if>
ThreadPool.<xsl:value-of select="$level1Count"/>.Server=<xsl:value-of select="@name"/>
<xsl:for-each select="ns:threadPool">
ThreadPool.<xsl:value-of select="$level1Count"/>.<xsl:value-of select="position()"/>.name=<xsl:value-of select="@name"/>
ThreadPool.<xsl:value-of select="$level1Count"/>.<xsl:value-of select="position()"/>.maximumSize=<xsl:value-of select="@maximumSize"/>
ThreadPool.<xsl:value-of select="$level1Count"/>.<xsl:value-of select="position()"/>.minimumSize=<xsl:value-of select="@minimumSize"/>
</xsl:for-each>	 
</xsl:for-each>	   
</xsl:template>
<xsl:template match="ns:SIBMessagingEngine">

# SIBMessagingEngine performance tuning parameters
<xsl:for-each select="ns:BusEngine">
BusEngine.<xsl:value-of select="position()"/>.name=<xsl:value-of select="@name"/>
BusEngine.<xsl:value-of select="position()"/>.busName=<xsl:value-of select="@busName"/>
BusEngine.<xsl:value-of select="position()"/>.sib.msgstore.cachedDataBufferSize=<xsl:value-of select="@sib.msgstore.cachedDataBufferSize"/>
BusEngine.<xsl:value-of select="position()"/>.sib.msgstore.discardableDataBufferSize=<xsl:value-of select="@sib.msgstore.discardableDataBufferSize"/>
</xsl:for-each>	   
</xsl:template>
<xsl:template match="ns:WebContainer">

# WebContainer performance tuning parameters
<xsl:for-each select="ns:Server">
<xsl:variable name="level1Count" select="position()"/>
<xsl:if test="$level1Count!=1">
<xsl:call-template name="Newline" />
</xsl:if>
WebContainer.<xsl:value-of select="$level1Count"/>.Server=<xsl:value-of select="@name"/>
WebContainer.<xsl:value-of select="$level1Count"/>.enableServletCaching=<xsl:value-of select="ns:WC/@enableServletCaching"/>
WebContainer.<xsl:value-of select="$level1Count"/>.SessionManager.allowOverflow=<xsl:value-of select="ns:WC/ns:SessionManager/ns:maxInMemorySessionCount/@allowOverflow"/>
WebContainer.<xsl:value-of select="$level1Count"/>.SessionManager.maxInMemorySessionCount=<xsl:value-of select="ns:WC/ns:SessionManager/ns:maxInMemorySessionCount/@maxInMemorySessionCount"/>
<xsl:for-each select="ns:HTTPInboundChannels/ns:HTTPInboundChannel">
WebContainer.<xsl:value-of select="$level1Count"/>.HTTPInboundChannel_<xsl:value-of select="position()"/>.name=<xsl:value-of select="@name"/>
WebContainer.<xsl:value-of select="$level1Count"/>.HTTPInboundChannel_<xsl:value-of select="position()"/>.maximumPersistentRequests=<xsl:value-of select="@maximumPersistentRequests"/>
WebContainer.<xsl:value-of select="$level1Count"/>.HTTPInboundChannel_<xsl:value-of select="position()"/>.persistentTimeout=<xsl:value-of select="@persistentTimeout"/>
</xsl:for-each>	 
</xsl:for-each>	   
</xsl:template>

<xsl:template match="ns:WorkManagerInfos">

# WorkManagerInfo performance tuning parameters
<xsl:for-each select="ns:WorkManagerInfo">
WorkManagerInfo.<xsl:value-of select="position()"/>.jndiName=<xsl:value-of select="@jndiName"/>
WorkManagerInfo.<xsl:value-of select="position()"/>.maxThreads=<xsl:value-of select="@maxThreads"/>
WorkManagerInfo.<xsl:value-of select="position()"/>.minThreads=<xsl:value-of select="@minThreads"/>
WorkManagerInfo.<xsl:value-of select="position()"/>.numAlarmThreads=<xsl:value-of select="@numAlarmThreads"/>
WorkManagerInfo.<xsl:value-of select="position()"/>.workReqQSize=<xsl:value-of select="@workReqQSize"/>
</xsl:for-each>	   
</xsl:template>
<xsl:template name="Newline"><xsl:text>
</xsl:text></xsl:template>
</xsl:stylesheet>