#BEGIN COPYRIGHT
#*************************************************************************
#
# Licensed Materials - Property of IBM
# 5725-C94, 5725-C95, 5725-C96
# (C) Copyright IBM Corporation 2013. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
#*************************************************************************
#END COPYRIGHT
# This script will enable/disable the auto start of all applications/schedulers for Migration purpose

# TODO: US 126453 - Multiple DE support, need to think about the scope (Pass in the cluster info from invoker?)
#                   Defined clusters for source environment
#                   DE for target environment

import sys;
from java.lang import *;
from java.util.logging import Logger;
from java.util.logging import Level;

__file__ = "setAutoStartPropForMigration.py"
logger = Logger.getLogger("setAutoStartPropForMigration.py");

def setAutoStartTagForApplications(enabled, cluster):
    #applications=AdminApp.list().splitlines()

    applications=AdminApp.list().split(lineSeparator)
    for application in applications:
        #print 'start to process application ' + application
        appDeployment = AdminConfig.getid('/Deployment:' + application + '/')
        depObject = AdminConfig.showAttribute(appDeployment, 'deployedObject')
        matchCluster = 0
        if cluster != "":
            deploymentTargets = AdminConfig.showAttribute(appDeployment, 'deploymentTargets')
            deploymentTargetList=[]
            if (len(deploymentTargets)>0 and deploymentTargets[0]=='[' and deploymentTargets[-1]==']'):
                if (deploymentTargets.find('"') == -1):
                    deploymentTargetList = deploymentTargets[1:-1].split() #splits space-separated lists,
                else:
                    deploymentTargets = deploymentTargets[1:-1]
                    index = 0
                    start = deploymentTargets.find('"')                
                    end = deploymentTargets.find('"',start+1)
                    while (start != -1 and end != -1):
                        deploymentTargetList.append(deploymentTargets[start+1:end])
                        index = index + 1
                        start = deploymentTargets.find('"',end + 1)
                        end = deploymentTargets.find('"',start + 1)
            for dt in deploymentTargetList:
                clusterName = AdminConfig.showAttribute(dt, 'name')
                if clusterName == cluster:
                    matchCluster = 1
            if matchCluster != 1:
                continue

        targetMappings = AdminConfig.showAttribute(depObject, 'targetMappings')
        #print targetMappings
        targetMappingList=[]
        if (len(targetMappings)>0 and targetMappings[0]=='[' and targetMappings[-1]==']'):
            if (targetMappings.find('"') == -1):
                targetMappingList = targetMappings[1:-1].split() #splits space-separated lists,
            else:
                targetMappings = targetMappings[1:-1]
                index = 0
                start = targetMappings.find('"')                
                end = targetMappings.find('"',start+1)                
                while (start != -1 and end != -1):
                    targetMappingList.append(targetMappings[start+1:end])
                    index = index + 1
                    start = targetMappings.find('"',end + 1)
                    end = targetMappings.find('"',start + 1)                
        else:
            targetMappingList = targetMappings.splitlines(lineSeparator)

        print 'Change auto start setting of application: '+application
        logger.log(Level.INFO, "Change auto start setting of application: " + application);
        for targetMapping in targetMappingList:
            #print 'target mapping:' + targetMapping
            status = AdminConfig.showAttribute(targetMapping, 'enable')
            #print 'Current auto-start is:' + status
            if enabled == 'false':
                AdminConfig.modify(targetMapping, '[[enable "false"]]')
            else:
                AdminConfig.modify(targetMapping, '[[enable "true"]]')
        
    AdminConfig.save()

def restartServers():
    
    cells = AdminConfig.list('Cell').split(lineSeparator)
    
    for cell in cells:
        nodes = AdminConfig.list('Node', cell).split(lineSeparator)
        for node in nodes:
            cname = AdminConfig.showAttribute(cell, 'name')
            nname = AdminConfig.showAttribute(node, 'name')
            #servers = AdminConfig.getid('/Node:' + nname + '/Server:/')
            servers = AdminControl.queryNames('type=Server,cell=' + cname +',node=' + nname + ',*')
            #print 'cell name:' + cname
            #print 'node name:' + nname
            #print 'servers:' + servers
            serverList = servers.split(lineSeparator)
            print 'Number of running servers on node ' + nname + ': %s \n' % (len(serverList))
            logger.log(Level.INFO, "Number of running servers on node " + nname + ": %s \n" % (len(serverList)));
            for server in serverList:
                sname = AdminControl.getAttribute(server, 'name')
                ptype = AdminControl.getAttribute(server, 'processType')               
                state = AdminControl.getAttribute(server, 'state')                
                if state == 'STARTED' and ptype == 'ManagedProcess':
                    #print 'node name:' + nname + '\nserver name:' + server + '\nstate:' + state
                    print 'About to stop server ' + server
                    logger.log(Level.INFO, "About to stop server " + server);
                    AdminControl.stopServer(sname,nname)      
                    print 'Complete stopping server ' + server
                    logger.log(Level.INFO, "Complete stopping server " + server);
                    
                    print 'About to start server ' + server
                    logger.log(Level.INFO, "About to start server " + server);
                    AdminControl.startServer(sname,nname)
                    print 'Complete starting server ' + server
                    logger.log(Level.INFO, "Complete starting server " + server);

def setDaemonAutoStart(schedulerName, flag, cluster):
    clusterScope = "/";
    if cluster != "":
        clusterScope = "/ServerCluster:" + cluster + "/SchedulerProvider:SchedulerProvider/"
    schedulerId = AdminConfig.getid(clusterScope + "SchedulerConfiguration:" + schedulerName + "/")
    if schedulerId == "":
        return
    
    print "**********************************************************************"
    print "Begin to set auto start of scheduler deamon (" + schedulerName + ") to " + flag
    print "schedulerId is "+schedulerId
    
    logger.log(Level.INFO, "**********************************************************************")
    logger.log(Level.INFO, "Begin to set auto start of scheduler deamon (" + schedulerName + ") to " + flag);
    logger.log(Level.INFO, "schedulerId is "+schedulerId);
    propertySet = AdminConfig.showAttribute(schedulerId, 'propertySet')
    disableDaemonAutoStartProp = [["name", "daemonAutoStart"], ["value", flag], ["type", 'java.lang.String']]
    updated = 'false'
    #print propertySet
    if propertySet == None:
        print 'Will create new propertySet and add new property'
        logger.log(Level.INFO, "Will create new propertySet and add new property");
        newPropSet = AdminConfig.create('J2EEResourcePropertySet', schedulerId, [])
        #print newPropSet
        resourceProperty = AdminConfig.create('J2EEResourceProperty', newPropSet, disableDaemonAutoStartProp)
        #print resourceProperty
    else:
        print 'PropertySet already exist'
        logger.log(Level.INFO, "PropertySet already exist");
        properties = AdminConfig.list("J2EEResourceProperty", propertySet).splitlines()
        #print properties
        for property in properties:
            #print property
            if AdminConfig.showAttribute(property, "name") == 'daemonAutoStart':
                print 'Modifying existing property'
                logger.log(Level.INFO, "Modifying existing property");
                AdminConfig.modify(property, disableDaemonAutoStartProp)
                updated = 'true'
        # No daemonAutoStart propety exist, create a new one
        if updated == 'false':
            print 'Create new property'
            logger.log(Level.INFO, "Create new property");
            resourceProperty = AdminConfig.create('J2EEResourceProperty', propertySet, disableDaemonAutoStartProp)
    #print AdminConfig.required('J2EEResourceProperty')
    AdminConfig.save()
#endDef

def setAutoStartTagForSchedulers(flag, cluster):
    BPMSchedulers=["BPEScheduler", "AppScheduler", "ProcessCenterSharingScheduler"]
    if flag == 'false' or flag == 'true':
        for scheduler in BPMSchedulers:
            setDaemonAutoStart(scheduler, flag, cluster)
    else:
        print 'No valid parameter used, we just support true/false'
        logger.log(Level.INFO, "No valid parameter used, we just support true/false");
#endDef

# get the input parameter: true/false to enable or disable auto start
flag = sys.argv[0]
if len(sys.argv) > 1:
    clusterArray = sys.argv[1].split(",")
    #print len(clusterArray)

lineSeparator=System.getProperty('line.separator')
if len(sys.argv) >=1 and sys.argv[0] != '':
    print 'Begin to set auto start for all applications to (' + flag +')'
    logger.log(Level.INFO, "Begin to set auto start for all applications to (" + flag + ")");
    if len(sys.argv) > 1:
        for cluster in clusterArray:
            setAutoStartTagForApplications(flag, cluster)
    else:
        print "It's StandAlone server"
        setAutoStartTagForApplications(flag, "")
    print 'Auto start for all applications was set to (' + flag + ') successfully'
    logger.log(Level.INFO, "Auto start for all applications was set to (" + flag + ") successfully");

    print ''
    print 'Begin to set the auto start property of BPM schedulers to (' + flag + ')'
    logger.log(Level.INFO, "Begin to set the auto start property of BPM schedulers to (" + flag + ")");
    if len(sys.argv) > 1:
        for cluster in clusterArray:
            setAutoStartTagForSchedulers(flag, cluster)
    else:
        print "It's StandAlone server"
        setAutoStartTagForSchedulers(flag, "")
    print 'Auto start of BPM scheduler daemon was set to (' + flag + ') successfully'
    logger.log(Level.INFO, "Auto start of BPM scheduler daemon was set to (" + flag + ") successfully");
    print ''
    #restartServers()
