#BEGIN COPYRIGHT
#*************************************************************************
#
# Licensed Materials - Property of IBM
# 5725-C94, 5725-C95, 5725-C96
# (C) Copyright IBM Corporation 2013. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
#*************************************************************************
#END COPYRIGHT
#=======================================================================================================================================================
# The script is used to fix the CEI emitter factory JNDI name.
# For Help:
#     >> ./wsadmin.sh -lang jython -f setCEIDestination.py
# 
# Supported parameters:
#   either a or application-cluster-name [required] 
#   either s or support-cluster-name [required]
#   no-save [options]
#   no-sync [options]
#
#==============================================================================
import getopt, sys
#==============================================================================

#------------------------------------------------------------------------------
# Print script usage
#------------------------------------------------------------------------------
def usage():
	print
	print "Usage:"
	print
	print "   setCEIDestination.py "
	print
	print "   -a, --application-cluster-name=NAME Specify the application cluster name."
	print "   -s, --support-cluster-name=NAME     Specify the support cluster name."
	print "       --no-sync                       Do not force the immediate propagation"
	print "                                       of changes across nodes."
	print "       --no-save                       Do not save configuration changes."
	print "       --help                          Display this help"

#------------------------------------------------------------------------------
# Fix the JNDI name
#------------------------------------------------------------------------------
def fixBPCCEIJNDIName(applicationClusterName, supportClusterName):
	emitterFactoryJndi = 'cell/clusters/%s/com/ibm/events/configuration/emitter/Default' % supportClusterName
	members = AdminConfig.getid('/ServerCluster:%s/ClusterMember:/' % applicationClusterName).splitlines()
	for member in members:
		nodeName = AdminConfig.showAttribute(member, 'nodeName')
 		serverName = AdminConfig.showAttribute(member, 'memberName')
 		eventsServices = AdminConfig.list('EventsService', AdminConfig.getid('/Node:%s/Server:%s/' % (nodeName,serverName))).splitlines()
		print "XXXX0000I: Updating configuration on server %s on node %s." % (serverName, nodeName) 
		for eventsService in eventsServices:
			print "XXXX0000I: Current value:",AdminConfig.showAttribute(eventsService,'eventInfrastructureEmitterFactoryJNDIName')
			AdminConfig.modify(eventsService, [ ['eventInfrastructureEmitterFactoryJNDIName', emitterFactoryJndi] ])
			print "XXXX0000I: New value    :",AdminConfig.showAttribute(eventsService,'eventInfrastructureEmitterFactoryJNDIName')

#=======================================================================================================================================================
#
# Main setCEIDestination.py execution logic:
# 
#=======================================================================================================================================================

def main():
	try:
		options, args = getopt.getopt(sys.argv, "a:s:", ["no-save","no-sync","help", "application-cluster-name=", "support-cluster-name="])
	except getopt.GetoptError, err:
		print str(err)
		usage()
		return 2

	if args:
		usage()
	
	save = 1
	sync = 1
	applicationClusterName = None
	supportClusterName = None
	for option, arg in options:
		if option in ("-a", "--application-cluster-name"):
			applicationClusterName = arg
		elif option in ("-s", "--support-cluster-name"):
			supportClusterName = arg
		elif option == "--no-save":
			save = 0
			sync = 0
		elif option == "--no-sync":
			sync = 0
		elif option == "--help":
			usage()
			return
		else:
			assert 0, "un-handled option"
	
	if applicationClusterName is None:
		print "XXXX0000E: The application cluster name must be specified."
		usage()
		return 2
	
	if supportClusterName is None:
		print "XXXX0000E: The support cluster name must be specified."
		usage()
		return 2
	
	# lookup the application cluster
	applicationCluster = AdminConfig.getid('/ServerCluster:%s/' % applicationClusterName)
	if not applicationCluster:
		print
		print 'XXXX0000E: The specified application cluster, "%s", does not exist.' % applicationClusterName
		usage()
		return 2 
	
	# verify that application cluster is a BPC/HTM application cluster
	if not AdminConfig.getid('/ServerCluster:%s/BPCConfigExtension:/' % applicationClusterName):
		print
		print 'XXXX0000E: The specified cluster, "%s", is not an application cluster.' % applicationClusterName
		usage()
		return 2 
	
	# lookup the support cluster
	supportCluster = AdminConfig.getid('/ServerCluster:%s/' % supportClusterName)
	if not supportCluster:
		print
		print 'XXXX0000E: The specified support cluster, "%s", does not exist.' % supportClusterName
		usage()
		return 2 
		
	
	# set the event emitter factory jndi name
	fixBPCCEIJNDIName(applicationClusterName, supportClusterName)
	
	# save and sync
	if save:
		print "XXXX0000I: Configuration is being saved."
		AdminConfig.save()
		if sync:
			print "XXXX0000I: Synchronizing the configuration across all nodes."
			AdminNodeManagement.syncActiveNodes()
	
	print "XXXX0000I: Done."


if __name__ == "__main__":
	sys.exit(main())